@@ -12,7 +12,7 @@ mkdir src
 protoc -I=../proto -I=/usr/local/include --rust_out=./src cacheclient.proto controlclient.proto momento/auth.proto
 
 pushd src
-    echo "mod cacheclient;" >> lib.rs
-    echo "mod controlclient;" >> lib.rs
-    echo "mod auth;" >> lib.rs
- popd
+    echo "pub mod cacheclient;" >> lib.rs
+    echo "pub mod controlclient;" >> lib.rs
+    echo "pub mod auth;" >> lib.rs
+popd
